@@ -180,7 +180,8 @@ public:
     Value::DataSets & as_data_set(Tag const & tag);
 
     /// @brief Return a data set contained in an existing element (read-only).
-    DataSet const & as_data_set(Tag const & tag, unsigned int position) const;
+    std::shared_ptr<DataSet> const &
+    as_data_set(Tag const & tag, unsigned int position) const;
 
     /// @brief Test whether an existing element has binary type.
     bool is_binary(Tag const & tag) const;
