@@ -24,29 +24,24 @@ EchoSCU
     // Nothing else.
 }
 
-EchoSCU
-::~EchoSCU()
-{
-    // Nothing to do.
-}
-
 void
 EchoSCU
 ::echo() const
 {
     auto const message_id = this->_association.next_message_id();
     
-    message::CEchoRequest const request(
+    auto request = std::make_shared<message::CEchoRequest>(
         message_id, registry::VerificationSOPClass);
     this->_association.send_message(
-        request, request.get_affected_sop_class_uid());
-    
-    message::CEchoResponse const response = this->_association.receive_message();
-    if(response.get_message_id_being_responded_to() != message_id)
+        request, request->get_affected_sop_class_uid());
+
+    auto response = std::make_shared<message::CEchoResponse>(
+        this->_association.receive_message());
+    if(response->get_message_id_being_responded_to() != message_id)
     {
         std::ostringstream message;
         message << "DIMSE: Unexpected Response MsgId: "
-                << response.get_message_id_being_responded_to() 
+                << response->get_message_id_being_responded_to()
                 << "(expected: " << message_id << ")";
         throw Exception(message.str());
     }
