@@ -12,6 +12,7 @@
 #include <cstddef>
 #include <initializer_list>
 
+#include "odil/odil.h"
 #include "odil/Tag.h"
 #include "odil/Value.h"
 #include "odil/VR.h"
@@ -22,54 +23,56 @@ namespace odil
 /**
  * @brief Element of a DICOM data set.
  */
-class Element
+class ODIL_API Element
 {
 public:
 
     /// @brief VR of the element.
     VR vr;
 
-    /// @brief Constructor.
-    Element(Value const & value=Value(), VR const & vr=VR::INVALID);
+    /// @brief Constructor using the VR to create an according empty container.
+    Element(VR const & vr);
 
     /// @brief Constructor.
-    Element(Value::Integers const & value, VR const & vr=VR::INVALID);
+    Element(Value const & value, VR const & vr);
 
     /// @brief Constructor.
-    Element(Value::Reals const & value, VR const & vr=VR::INVALID);
+    Element(Value && value, VR const & vr);
 
-    /// @brief Constructor.
-    Element(Value::Strings const & value, VR const & vr=VR::INVALID);
+#define ODIL_ELEMENT_CONSTRUCTORS(type) \
+    Element(Value::type const & value, VR const & vr=VR::INVALID); \
+    Element(Value::type && value, VR const & vr=VR::INVALID); \
+    Element(\
+        std::initializer_list<Value::type::value_type> const & value, \
+        VR const & vr=VR::INVALID);
+    /*
+     * No need for for a rvalue reference version of std::initializer_list:
+     * copying a std::initializer_list does not copy the underlying objects.
+     */
 
-    /// @brief Constructor.
-    Element(Value::DataSets const & value, VR const & vr=VR::INVALID);
+    ODIL_ELEMENT_CONSTRUCTORS(Integers);
+    ODIL_ELEMENT_CONSTRUCTORS(Reals);
+    ODIL_ELEMENT_CONSTRUCTORS(Strings);
+    ODIL_ELEMENT_CONSTRUCTORS(DataSets);
+    ODIL_ELEMENT_CONSTRUCTORS(Binary);
+#undef ODIL_ELEMENT_CONSTRUCTORS
 
-    /// @brief Constructor.
-    Element(Value::Binary const & value, VR const & vr=VR::INVALID);
-
-    /// @brief Constructor.
     Element(
         std::initializer_list<int> const & value, VR const & vr=VR::INVALID);
 
-    /// @brief Constructor.
     Element(
-        std::initializer_list<Value::Integer> const & value,
+        std::initializer_list<std::initializer_list<uint8_t>> const & value,
         VR const & vr=VR::INVALID);
 
-    /// @brief Constructor.
-    Element(
-        std::initializer_list<Value::Real> const & value,
-        VR const & vr=VR::INVALID);
-
-    /// @brief Constructor.
-    Element(
-        std::initializer_list<Value::String> const & value,
-        VR const & vr=VR::INVALID);
-
-    /// @brief Constructor.
-    Element(
-        std::initializer_list<DataSet> const & value,
-        VR const & vr=VR::INVALID);
+    /** @addtogroup default_operations Default class operations
+     * @{
+     */
+    ~Element() =default;
+    Element(Element const &) =default;
+    Element(Element &&) =default;
+    Element & operator=(Element const &) =default;
+    Element & operator=(Element &&) =default;
+    /// @}
 
     /// @brief Test whether the element is empty.
     bool empty() const;
@@ -170,31 +173,11 @@ public:
 
     /// @brief Difference test
     bool operator!=(Element const & other) const;
+    
+    /// @brief Clear the element (element.empty() will be true).
+    void clear();
 
 private:
-    struct Empty
-    {
-        typedef bool result_type;
-
-        template<typename T>
-        bool operator()(T const & container) const
-        {
-            return container.empty();
-        }
-    };
-
-    struct Size
-    {
-        typedef std::size_t result_type;
-
-        template<typename T>
-        std::size_t operator()(T const & container) const
-        {
-            return container.size();
-        }
-    };
-
-
     Value _value;
 };
 
@@ -211,3 +194,4 @@ apply_visitor(TVisitor const & visitor, Element const & element);
 #include "odil/Element.txx"
 
 #endif // _9c3d8f32_0310_4e3a_b5d2_6d69f229a2cf
+
