@@ -24,7 +24,7 @@ CMoveRequest
 ::CMoveRequest(
     Value::Integer message_id, Value::String const & affected_sop_class_uid,
     Value::Integer priority, Value::String const & move_destination,
-    DataSet const & dataset)
+    std::shared_ptr<DataSet> dataset)
 : Request(message_id)
 {
     this->_create(affected_sop_class_uid, priority, move_destination, dataset);
@@ -32,36 +32,11 @@ CMoveRequest
 }
 
 CMoveRequest
-::CMoveRequest(
-    Value::Integer message_id, Value::String const & affected_sop_class_uid,
-    Value::Integer priority, Value::String const & move_destination,
-    DataSet && dataset)
-: Request(message_id)
-{
-    this->_create(affected_sop_class_uid, priority, move_destination, dataset);
-    this->set_data_set(std::move(dataset));
-}
-
-CMoveRequest
-::CMoveRequest(Message const & message)
+::CMoveRequest(std::shared_ptr<Message> message)
 : Request(message)
 {
     this->_parse(message);
-    this->set_data_set(message.get_data_set());
-}
-
-CMoveRequest
-::CMoveRequest(Message && message)
-: Request(message)
-{
-    this->_parse(message);
-    this->set_data_set(std::move(message.get_data_set()));
-}
-
-CMoveRequest
-::~CMoveRequest()
-{
-    // Nothing to do.
+    this->set_data_set(message->get_data_set());
 }
 
 void
@@ -69,13 +44,13 @@ CMoveRequest
 ::_create(
     Value::String const & affected_sop_class_uid,
     Value::Integer priority, Value::String const & move_destination,
-    DataSet const & dataset)
+    std::shared_ptr<DataSet const> dataset)
 {
     this->set_command_field(Command::C_MOVE_RQ);
     this->set_affected_sop_class_uid(affected_sop_class_uid);
     this->set_priority(priority);
     this->set_move_destination(move_destination);
-    if(dataset.empty())
+    if(!dataset || dataset->empty())
     {
         throw Exception("Data set is required");
     }
@@ -83,23 +58,23 @@ CMoveRequest
 
 void
 CMoveRequest
-::_parse(Message const & message)
+::_parse(std::shared_ptr<Message const> message)
 {
-    if(message.get_command_field() != Command::C_MOVE_RQ)
+    if(!message || message->get_command_field() != Command::C_MOVE_RQ)
     {
         throw Exception("Message is not a C-MOVE-RQ");
     }
-    this->set_command_field(message.get_command_field());
+    this->set_command_field(message->get_command_field());
 
     this->set_affected_sop_class_uid(
-        message.get_command_set().as_string(registry::AffectedSOPClassUID, 0));
+        message->get_command_set()->as_string(registry::AffectedSOPClassUID, 0));
 
-    this->set_priority(message.get_command_set().as_int(registry::Priority, 0));
+    this->set_priority(message->get_command_set()->as_int(registry::Priority, 0));
 
     this->set_move_destination(
-        message.get_command_set().as_string(registry::MoveDestination, 0));
+        message->get_command_set()->as_string(registry::MoveDestination, 0));
 
-    if(!message.has_data_set()  || message.get_data_set().empty())
+    if(!message->has_data_set()  || message->get_data_set()->empty())
     {
         throw Exception("Data set is required");
     }
