@@ -16,13 +16,14 @@
 #include "odil/Exception.h"
 #include "odil/SCP.h"
 #include "odil/Reader.h"
+#include "odil/Value.h"
 #include "odil/message/Response.h"
 
 struct Status
 {
     int client;
     std::string server;
-    std::vector<odil::DataSet> responses;
+    odil::Value::DataSets responses;
 };
 
 class Generator: public odil::SCP::DataSetGenerator
@@ -38,17 +39,17 @@ public:
         // Nothing to do.
     }
 
-    virtual void initialize(odil::message::Request const & )
+    virtual void initialize(std::shared_ptr<odil::message::Request const>)
     {
-        odil::DataSet data_set_1;
-        data_set_1.add(odil::registry::PatientName, {"Hello^World"});
-        data_set_1.add(odil::registry::PatientID, {"1234"});
-        this->_responses.push_back(std::move(data_set_1));
+        auto data_set_1 = std::make_shared<odil::DataSet>();
+        data_set_1->add(odil::registry::PatientName, {"Hello^World"});
+        data_set_1->add(odil::registry::PatientID, {"1234"});
+        this->_responses.push_back(data_set_1);
 
-        odil::DataSet data_set_2;
-        data_set_2.add(odil::registry::PatientName, {"Doe^John"});
-        data_set_2.add(odil::registry::PatientID, {"5678"});
-        this->_responses.push_back(std::move(data_set_2));
+        auto data_set_2 = std::make_shared<odil::DataSet>();
+        data_set_2->add(odil::registry::PatientName, {"Doe^John"});
+        data_set_2->add(odil::registry::PatientID, {"5678"});
+        this->_responses.push_back(data_set_2);
 
         this->_response_iterator = this->_responses.begin();
     }
@@ -58,9 +59,9 @@ public:
         return (this->_response_iterator == this->_responses.end());
     }
 
-    virtual odil::DataSet get() const
+    virtual std::shared_ptr<odil::DataSet> get() const
     {
-        return *std::make_move_iterator(this->_response_iterator);
+        return *this->_response_iterator;
     }
 
     virtual void next()
@@ -70,8 +71,8 @@ public:
 
 
 private:
-    mutable std::vector<odil::DataSet> _responses;
-    std::vector<odil::DataSet>::iterator _response_iterator;
+    mutable odil::Value::DataSets _responses;
+    odil::Value::DataSets::iterator _response_iterator;
 };
 
 void run_server(Status * status)
@@ -135,7 +136,7 @@ void run_client(Status * status)
 
         std::ifstream stream(it->path().string());
         auto data_set = odil::Reader::read_file(stream).second;
-        status->responses.push_back(std::move(data_set));
+        status->responses.push_back(data_set);
 
         boost::filesystem::remove(it->path());
     }
@@ -156,11 +157,11 @@ BOOST_AUTO_TEST_CASE(Release)
     BOOST_REQUIRE_EQUAL(status.server, "release");
     BOOST_REQUIRE_EQUAL(status.responses.size(), 2);
 
-    BOOST_REQUIRE_EQUAL(status.responses[0].size(), 2);
-    BOOST_REQUIRE_EQUAL(status.responses[0].as_string("PatientName", 0), "Hello^World");
-    BOOST_REQUIRE_EQUAL(status.responses[0].as_string("PatientID", 0), "1234");
+    BOOST_REQUIRE_EQUAL(status.responses[0]->size(), 2);
+    BOOST_REQUIRE_EQUAL(status.responses[0]->as_string("PatientName", 0), "Hello^World");
+    BOOST_REQUIRE_EQUAL(status.responses[0]->as_string("PatientID", 0), "1234");
 
-    BOOST_REQUIRE_EQUAL(status.responses[1].size(), 2);
-    BOOST_REQUIRE_EQUAL(status.responses[1].as_string("PatientName", 0), "Doe^John");
-    BOOST_REQUIRE_EQUAL(status.responses[1].as_string("PatientID", 0), "5678");
+    BOOST_REQUIRE_EQUAL(status.responses[1]->size(), 2);
+    BOOST_REQUIRE_EQUAL(status.responses[1]->as_string("PatientName", 0), "Doe^John");
+    BOOST_REQUIRE_EQUAL(status.responses[1]->as_string("PatientID", 0), "5678");
 }
