@@ -10,30 +10,31 @@
 
 struct Fixture: public PeerFixtureBase
 {
-    odil::DataSet dataset;
+    std::shared_ptr<odil::DataSet> dataset;
 
     Fixture()
     : PeerFixtureBase({
-        {
-            1, odil::registry::RawDataStorage,
-            {odil::registry::ImplicitVRLittleEndian}, true, false
-        }
-    })
+            {
+                1, odil::registry::RawDataStorage,
+                {odil::registry::ImplicitVRLittleEndian}, true, false
+            }
+        }),
+        dataset(std::make_shared<odil::DataSet>())
     {
-        this->dataset.add("ImageType", {"ORIGINAL", "PRIMARY", "OTHER"});
-        this->dataset.add("PatientID", {"1234"});
-        this->dataset.add("StudyInstanceUID", {"2.25.386726390606491051215227596277040710"});
-        this->dataset.add("SeriesInstanceUID", {"2.25.235367796740370588607388995952651763168"});
-        this->dataset.add("SOPClassUID", {odil::registry::RawDataStorage});
-        this->dataset.add("SOPInstanceUID", {"2.25.294312554735929033890522327215919068328"});
+        this->dataset->add("ImageType", {"ORIGINAL", "PRIMARY", "OTHER"});
+        this->dataset->add("PatientID", {"1234"});
+        this->dataset->add("StudyInstanceUID", {"2.25.386726390606491051215227596277040710"});
+        this->dataset->add("SeriesInstanceUID", {"2.25.235367796740370588607388995952651763168"});
+        this->dataset->add("SOPClassUID", {odil::registry::RawDataStorage});
+        this->dataset->add("SOPInstanceUID", {"2.25.294312554735929033890522327215919068328"});
     }
 
 };
 
 BOOST_FIXTURE_TEST_CASE(AffectedSOPClassUID, Fixture)
 {
-    odil::DataSet dataset;
-    dataset.add("SOPClassUID", {odil::registry::RawDataStorage});
+    auto dataset = std::make_shared<odil::DataSet>();
+    dataset->add("SOPClassUID", {odil::registry::RawDataStorage});
 
     odil::StoreSCU scu(this->association);
     scu.set_affected_sop_class(dataset);
@@ -42,7 +43,7 @@ BOOST_FIXTURE_TEST_CASE(AffectedSOPClassUID, Fixture)
 
 BOOST_FIXTURE_TEST_CASE(AffectedSOPClassUIDNoSOPClassUID, Fixture)
 {
-    odil::DataSet dataset;
+    auto dataset = std::make_shared<odil::DataSet>();
 
     odil::StoreSCU scu(this->association);
     BOOST_CHECK_THROW(scu.set_affected_sop_class(dataset), odil::Exception);
@@ -50,8 +51,8 @@ BOOST_FIXTURE_TEST_CASE(AffectedSOPClassUIDNoSOPClassUID, Fixture)
 
 BOOST_FIXTURE_TEST_CASE(AffectedSOPClassUIDUnknownSOPClassUID, Fixture)
 {
-    odil::DataSet dataset;
-    dataset.add("SOPClassUID", {"invalid"});
+    auto dataset = std::make_shared<odil::DataSet>();
+    dataset->add("SOPClassUID", {"invalid"});
 
     odil::StoreSCU scu(this->association);
     BOOST_CHECK_THROW(scu.set_affected_sop_class(dataset), odil::Exception);
